@@ -34,15 +34,4 @@ __attribute__((visibility("default")))
 
 @end
 
-__attribute__((visibility("default")))
-@interface AAITimerWrapper : NSObject
-
-@property(nonatomic, weak) NSTimer *timer;
-
-+ (AAITimerWrapper *)scheduledTimerWithTimeInterval:(NSTimeInterval)timeInterval
-                                            repeats:(BOOL)repeats
-                                          execBlock:(void(^)(AAITimerWrapper *timerWrapper))execBlock;
-- (void)invalidate;
-
-@end
 NS_ASSUME_NONNULL_END
