@@ -172,6 +172,41 @@ __attribute__((visibility("default")))
 /// @param state Local language string of the key
 /// @param key The state key
 /// @discussion You can override this method to make some additional settings for `_stateLabel`, such as frame, content, etc.
+///
+/// In other words, this method is always called when the UI needs to update, and can essentially serve as a replacement for the unavailable  property `frameDetectedBlk`."
+///
+/// All available key as follows:
+/// @code
+/// "no_face"
+/// "move_further"
+/// "move_closer"
+/// "move_center"
+/// "frontal"
+/// "stay_still"
+/// "pls_blink"
+/// "pls_turn_head"
+/// "pls_open_mouth"
+/// "face_occ"
+/// "pls_open_eye"
+/// "low_light"
+/// "high_light"
+/// "face_move_left"
+/// "face_move_right"
+/// "face_move_upper"
+/// "face_move_down"
+/// "pls_blink"
+/// "warn_muti_face"
+///
+/// "fail_reason_timeout"
+/// "fail_reason_muti_face"
+/// "fail_reason_facemiss_pos_yaw"
+/// "fail_reason_facemiss_blink_mouth"
+/// "fail_reason_much_action"
+/// "no_camera_permission"
+/// "device_not_support"
+/// "detection_success"
+/// @endcode
+///
 /// @since 1.2.3
 - (void)updateStateLabel:(NSString * _Nullable)state key:(NSString * _Nullable)key;
 
@@ -181,6 +216,7 @@ __attribute__((visibility("default")))
 - (void)resetViewState;
 
 /// @abstract When liveness detection failed, you can call this method to retry it.
+/// @warning Calling this method while liveness detection is running is prohibited. The SDK will ignore any such calls.
 /// @since 1.2.3
 - (void)restartDetection;
 
@@ -312,7 +348,7 @@ __attribute__((visibility("default")))
 
 /// @abstract Called whenever a new video frame is detected.
 /// @since 1.2.3
-@property(nonatomic, copy, nullable) void (^frameDetectedBlk)(AAILivenessViewController *rawVC, AAILivenessStage livenessStage, AAIActionStatus status, AAIDetectionResult result, NSDictionary *info) AAI_LD_UNAVAILABLE_FROM(4.0.0);
+@property(nonatomic, copy, nullable) void (^frameDetectedBlk)(AAILivenessViewController *rawVC, AAILivenessStage livenessStage, AAIActionStatus status, AAIDetectionResult result, NSDictionary *info) AAI_LD_UNAVAILABLE_FROM(4.0.0, "Using `- (void)updateStateLabel:(NSString * _Nullable)state key:(NSString * _Nullable)key` instead");
 
 /// @abstract Indicates that the liveness detection type is about to be changed.
 ///
